@@ -800,16 +800,11 @@ bluez_vanished_cb (GDBusConnection *connection,
 {
 	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE(client);
 
-	if (priv->default_adapter)
-		g_clear_pointer (&priv->default_adapter,
-				 gtk_tree_row_reference_free);
+	g_clear_pointer (&priv->default_adapter, gtk_tree_row_reference_free);
 
 	gtk_tree_store_clear (priv->store);
 
-	if (priv->manager) {
-		g_object_unref (priv->manager);
-		priv->manager = NULL;
-	}
+	g_clear_object (&priv->manager);
 }
 
 static void bluetooth_client_init(BluetoothClient *client)
@@ -976,7 +971,6 @@ _bluetooth_client_set_discoverable (BluetoothClient *client,
 					g_variant_new_variant (g_variant_new_boolean (discoverable)),
 					NULL, &error);
 	if (ret == FALSE) {
-
 		g_warning ("Failed to set Discoverable to %d: %s", discoverable, error->message);
 		g_error_free (error);
 	}
@@ -1093,12 +1087,10 @@ static void bluetooth_client_finalize(GObject *client)
 
 	g_bus_unwatch_name (priv->owner_change_id);
 
-	if (priv->manager)
-		g_object_unref (priv->manager);
+	g_clear_object (&priv->manager);
+	g_object_unref (priv->store);
 
-	g_object_unref(priv->store);
-
-	gtk_tree_row_reference_free (priv->default_adapter);
+	g_clear_pointer (&priv->default_adapter, gtk_tree_row_reference_free);
 
 	G_OBJECT_CLASS(bluetooth_client_parent_class)->finalize(client);
 }
@@ -1649,8 +1641,7 @@ bluetooth_client_dump_device (GtkTreeModel *model,
 	g_free (alias);
 	g_free (address);
 	g_free (icon);
-	if (proxy != NULL)
-		g_object_unref (proxy);
+	g_clear_object (&proxy);
 	g_strfreev (uuids);
 }
 
